@@ -1,7 +1,7 @@
 #!/usr/bin/python2.4
 # -*- coding: utf-8 -*-#
 #
-# Copyright 2007 Google Inc. All Rights Reserved.
+# Copyright 2007 The Python-Twitter Developers
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,19 +17,20 @@
 
 '''Unit tests for the twitter.py library'''
 
-__author__ = 'dewitt@google.com'
+__author__ = 'python-twitter@googlegroups.com'
 
 import os
 import simplejson
 import time
 import calendar
 import unittest
+import urllib
 
 import twitter
 
 class StatusTest(unittest.TestCase):
 
-  SAMPLE_JSON = '''{"created_at": "Fri Jan 26 23:17:14 +0000 2007", "id": 4391023, "text": "A l\u00e9gp\u00e1rn\u00e1s haj\u00f3m tele van angoln\u00e1kkal.", "user": {"description": "Canvas. JC Penny. Three ninety-eight.", "id": 718443, "location": "Okinawa, Japan", "name": "Kesuke Miyagi", "profile_image_url": "http://twitter.com/system/user/profile_image/718443/normal/kesuke.png", "screen_name": "kesuke", "url": "http://twitter.com/kesuke"}}'''
+  SAMPLE_JSON = '''{"created_at": "Fri Jan 26 23:17:14 +0000 2007", "id": 4391023, "text": "A l\u00e9gp\u00e1rn\u00e1s haj\u00f3m tele van angoln\u00e1kkal.", "user": {"description": "Canvas. JC Penny. Three ninety-eight.", "id": 718443, "location": "Okinawa, Japan", "name": "Kesuke Miyagi", "profile_image_url": "https://twitter.com/system/user/profile_image/718443/normal/kesuke.png", "screen_name": "kesuke", "url": "https://twitter.com/kesuke"}}'''
 
   def _GetSampleUser(self):
     return twitter.User(id=718443,
@@ -37,8 +38,8 @@ class StatusTest(unittest.TestCase):
                         screen_name='kesuke',
                         description=u'Canvas. JC Penny. Three ninety-eight.',
                         location='Okinawa, Japan',
-                        url='http://twitter.com/kesuke',
-                        profile_image_url='http://twitter.com/system/user/pro'
+                        url='https://twitter.com/kesuke',
+                        profile_image_url='https://twitter.com/system/user/pro'
                                           'file_image/718443/normal/kesuke.pn'
                                           'g')
 
@@ -158,7 +159,7 @@ class StatusTest(unittest.TestCase):
 
 class UserTest(unittest.TestCase):
 
-  SAMPLE_JSON = '''{"description": "Indeterminate things", "id": 673483, "location": "San Francisco, CA", "name": "DeWitt", "profile_image_url": "http://twitter.com/system/user/profile_image/673483/normal/me.jpg", "screen_name": "dewitt", "status": {"created_at": "Fri Jan 26 17:28:19 +0000 2007", "id": 4212713, "text": "\\"Select all\\" and archive your Gmail inbox.  The page loads so much faster!"}, "url": "http://unto.net/"}'''
+  SAMPLE_JSON = '''{"description": "Indeterminate things", "id": 673483, "location": "San Francisco, CA", "name": "DeWitt", "profile_image_url": "https://twitter.com/system/user/profile_image/673483/normal/me.jpg", "screen_name": "dewitt", "status": {"created_at": "Fri Jan 26 17:28:19 +0000 2007", "id": 4212713, "text": "\\"Select all\\" and archive your Gmail inbox.  The page loads so much faster!"}, "url": "http://unto.net/"}'''
 
   def _GetSampleStatus(self):
     return twitter.Status(created_at='Fri Jan 26 17:28:19 +0000 2007',
@@ -173,7 +174,7 @@ class UserTest(unittest.TestCase):
                         description=u'Indeterminate things',
                         location='San Francisco, CA',
                         url='http://unto.net/',
-                        profile_image_url='http://twitter.com/system/user/prof'
+                        profile_image_url='https://twitter.com/system/user/prof'
                                           'ile_image/673483/normal/me.jpg',
                         status=self._GetSampleStatus())
 
@@ -185,8 +186,8 @@ class UserTest(unittest.TestCase):
                         name='DeWitt',
                         screen_name='dewitt',
                         description=u'Indeterminate things',
-                        url='http://twitter.com/dewitt',
-                        profile_image_url='http://twitter.com/system/user/prof'
+                        url='https://twitter.com/dewitt',
+                        profile_image_url='https://twitter.com/system/user/prof'
                                           'ile_image/673483/normal/me.jpg',
                         status=self._GetSampleStatus())
 
@@ -203,9 +204,9 @@ class UserTest(unittest.TestCase):
     self.assertEqual('Indeterminate things', user.GetDescription())
     user.SetLocation('San Francisco, CA')
     self.assertEqual('San Francisco, CA', user.GetLocation())
-    user.SetProfileImageUrl('http://twitter.com/system/user/profile_im'
+    user.SetProfileImageUrl('https://twitter.com/system/user/profile_im'
                             'age/673483/normal/me.jpg')
-    self.assertEqual('http://twitter.com/system/user/profile_image/673'
+    self.assertEqual('https://twitter.com/system/user/profile_image/673'
                      '483/normal/me.jpg', user.GetProfileImageUrl())
     user.SetStatus(self._GetSampleStatus())
     self.assertEqual(4212713, user.GetStatus().id)
@@ -223,9 +224,9 @@ class UserTest(unittest.TestCase):
     self.assertEqual('Indeterminate things', user.description)
     user.location = 'San Francisco, CA'
     self.assertEqual('San Francisco, CA', user.location)
-    user.profile_image_url = 'http://twitter.com/system/user/profile_i' \
+    user.profile_image_url = 'https://twitter.com/system/user/profile_i' \
                              'mage/673483/normal/me.jpg'
-    self.assertEqual('http://twitter.com/system/user/profile_image/6734'
+    self.assertEqual('https://twitter.com/system/user/profile_image/6734'
                      '83/normal/me.jpg', user.profile_image_url)
     self.status = self._GetSampleStatus()
     self.assertEqual(4212713, self.status.id)
@@ -244,7 +245,7 @@ class UserTest(unittest.TestCase):
     self.assertEqual('dewitt', data['screen_name'])
     self.assertEqual('Indeterminate things', data['description'])
     self.assertEqual('San Francisco, CA', data['location'])
-    self.assertEqual('http://twitter.com/system/user/profile_image/6734'
+    self.assertEqual('https://twitter.com/system/user/profile_image/6734'
                      '83/normal/me.jpg', data['profile_image_url'])
     self.assertEqual('http://unto.net/', data['url'])
     self.assertEqual(4212713, data['status']['id'])
@@ -257,7 +258,7 @@ class UserTest(unittest.TestCase):
     user.screen_name = 'dewitt'
     user.description = 'Indeterminate things'
     user.location = 'San Francisco, CA'
-    user.profile_image_url = 'http://twitter.com/system/user/profile_image/67' \
+    user.profile_image_url = 'https://twitter.com/system/user/profile_image/67' \
                              '3483/normal/me.jpg'
     user.url = 'http://unto.net/'
     user.status = self._GetSampleStatus()
@@ -314,14 +315,17 @@ class ApiTest(unittest.TestCase):
 
   def setUp(self):
     self._urllib = MockUrllib()
-    api = twitter.Api(username='test', password='test')
-    api.SetCache(NullCache())
+    api = twitter.Api(consumer_key='CONSUMER_KEY',
+                      consumer_secret='CONSUMER_SECRET',
+                      access_token_key='OAUTH_TOKEN',
+                      access_token_secret='OAUTH_SECRET', 
+                      cache=None)
     api.SetUrllib(self._urllib)
     self._api = api
 
   def testTwitterError(self):
     '''Test that twitter responses containing an error message are wrapped.'''
-    self._AddHandler('http://twitter.com/statuses/public_timeline.json',
+    self._AddHandler('https://api.twitter.com/1/statuses/public_timeline.json',
                      curry(self._OpenTestData, 'public_timeline_error.json'))
     # Manually try/catch so we can check the exception's value
     try:
@@ -334,7 +338,7 @@ class ApiTest(unittest.TestCase):
 
   def testGetPublicTimeline(self):
     '''Test the twitter.Api GetPublicTimeline method'''
-    self._AddHandler('http://twitter.com/statuses/public_timeline.json?since_id=12345',
+    self._AddHandler('https://api.twitter.com/1/statuses/public_timeline.json?since_id=12345',
                      curry(self._OpenTestData, 'public_timeline.json'))
     statuses = self._api.GetPublicTimeline(since_id=12345)
     # This is rather arbitrary, but spot checking is better than nothing
@@ -343,16 +347,16 @@ class ApiTest(unittest.TestCase):
 
   def testGetUserTimeline(self):
     '''Test the twitter.Api GetUserTimeline method'''
-    self._AddHandler('http://twitter.com/statuses/user_timeline/kesuke.json?count=1&since=Tue%2C+27+Mar+2007+22%3A55%3A48+GMT',
+    self._AddHandler('https://api.twitter.com/1/statuses/user_timeline/kesuke.json?count=1',
                      curry(self._OpenTestData, 'user_timeline-kesuke.json'))
-    statuses = self._api.GetUserTimeline('kesuke', count=1, since='Tue, 27 Mar 2007 22:55:48 GMT')
+    statuses = self._api.GetUserTimeline('kesuke', count=1)
     # This is rather arbitrary, but spot checking is better than nothing
     self.assertEqual(89512102, statuses[0].id)
     self.assertEqual(718443, statuses[0].user.id)
 
   def testGetFriendsTimeline(self):
     '''Test the twitter.Api GetFriendsTimeline method'''
-    self._AddHandler('http://twitter.com/statuses/friends_timeline/kesuke.json',
+    self._AddHandler('https://api.twitter.com/1/statuses/friends_timeline/kesuke.json',
                      curry(self._OpenTestData, 'friends_timeline-kesuke.json'))
     statuses = self._api.GetFriendsTimeline('kesuke')
     # This is rather arbitrary, but spot checking is better than nothing
@@ -361,7 +365,7 @@ class ApiTest(unittest.TestCase):
 
   def testGetStatus(self):
     '''Test the twitter.Api GetStatus method'''
-    self._AddHandler('http://twitter.com/statuses/show/89512102.json',
+    self._AddHandler('https://api.twitter.com/1/statuses/show/89512102.json',
                      curry(self._OpenTestData, 'show-89512102.json'))
     status = self._api.GetStatus(89512102)
     self.assertEqual(89512102, status.id)
@@ -369,37 +373,37 @@ class ApiTest(unittest.TestCase):
 
   def testDestroyStatus(self):
     '''Test the twitter.Api DestroyStatus method'''
-    self._AddHandler('http://twitter.com/statuses/destroy/103208352.json',
+    self._AddHandler('https://api.twitter.com/1/statuses/destroy/103208352.json',
                      curry(self._OpenTestData, 'status-destroy.json'))
     status = self._api.DestroyStatus(103208352)
     self.assertEqual(103208352, status.id)
 
   def testPostUpdate(self):
     '''Test the twitter.Api PostUpdate method'''
-    self._AddHandler('http://twitter.com/statuses/update.json',
+    self._AddHandler('https://api.twitter.com/1/statuses/update.json',
                      curry(self._OpenTestData, 'update.json'))
-    status = self._api.PostUpdate(u'Моё судно на воздушной подушке полно угрей')
+    status = self._api.PostUpdate(u'Моё судно на воздушной подушке полно угрей'.encode('utf8'))
     # This is rather arbitrary, but spot checking is better than nothing
     self.assertEqual(u'Моё судно на воздушной подушке полно угрей', status.text)
 
   def testGetReplies(self):
     '''Test the twitter.Api GetReplies method'''
-    self._AddHandler('http://twitter.com/statuses/replies.json?page=1',
+    self._AddHandler('https://api.twitter.com/1/statuses/replies.json?page=1',
                      curry(self._OpenTestData, 'replies.json'))
     statuses = self._api.GetReplies(page=1)
     self.assertEqual(36657062, statuses[0].id)
 
   def testGetFriends(self):
     '''Test the twitter.Api GetFriends method'''
-    self._AddHandler('http://twitter.com/statuses/friends.json?page=1',
+    self._AddHandler('https://api.twitter.com/1/statuses/friends.json?cursor=123',
                      curry(self._OpenTestData, 'friends.json'))
-    users = self._api.GetFriends(page=1)
+    users = self._api.GetFriends(cursor=123)
     buzz = [u.status for u in users if u.screen_name == 'buzz']
     self.assertEqual(89543882, buzz[0].id)
 
   def testGetFollowers(self):
     '''Test the twitter.Api GetFollowers method'''
-    self._AddHandler('http://twitter.com/statuses/followers.json?page=1',
+    self._AddHandler('https://api.twitter.com/1/statuses/followers.json?page=1',
                      curry(self._OpenTestData, 'followers.json'))
     users = self._api.GetFollowers(page=1)
     # This is rather arbitrary, but spot checking is better than nothing
@@ -408,7 +412,7 @@ class ApiTest(unittest.TestCase):
 
   def testGetFeatured(self):
     '''Test the twitter.Api GetFeatured method'''
-    self._AddHandler('http://twitter.com/statuses/featured.json',
+    self._AddHandler('https://api.twitter.com/1/statuses/featured.json',
                      curry(self._OpenTestData, 'featured.json'))
     users = self._api.GetFeatured()
     # This is rather arbitrary, but spot checking is better than nothing
@@ -417,22 +421,22 @@ class ApiTest(unittest.TestCase):
 
   def testGetDirectMessages(self):
     '''Test the twitter.Api GetDirectMessages method'''
-    self._AddHandler('http://twitter.com/direct_messages.json?page=1',
+    self._AddHandler('https://api.twitter.com/1/direct_messages.json?page=1',
                      curry(self._OpenTestData, 'direct_messages.json'))
     statuses = self._api.GetDirectMessages(page=1)
     self.assertEqual(u'A légpárnás hajóm tele van angolnákkal.', statuses[0].text)
 
   def testPostDirectMessage(self):
     '''Test the twitter.Api PostDirectMessage method'''
-    self._AddHandler('http://twitter.com/direct_messages/new.json',
+    self._AddHandler('https://api.twitter.com/1/direct_messages/new.json',
                      curry(self._OpenTestData, 'direct_messages-new.json'))
-    status = self._api.PostDirectMessage('test', u'Моё судно на воздушной подушке полно угрей')
+    status = self._api.PostDirectMessage('test', u'Моё судно на воздушной подушке полно угрей'.encode('utf8'))
     # This is rather arbitrary, but spot checking is better than nothing
     self.assertEqual(u'Моё судно на воздушной подушке полно угрей', status.text)
 
   def testDestroyDirectMessage(self):
     '''Test the twitter.Api DestroyDirectMessage method'''
-    self._AddHandler('http://twitter.com/direct_messages/destroy/3496342.json',
+    self._AddHandler('https://api.twitter.com/1/direct_messages/destroy/3496342.json',
                      curry(self._OpenTestData, 'direct_message-destroy.json'))
     status = self._api.DestroyDirectMessage(3496342)
     # This is rather arbitrary, but spot checking is better than nothing
@@ -440,7 +444,7 @@ class ApiTest(unittest.TestCase):
 
   def testCreateFriendship(self):
     '''Test the twitter.Api CreateFriendship method'''
-    self._AddHandler('http://twitter.com/friendships/create/dewitt.json',
+    self._AddHandler('https://api.twitter.com/1/friendships/create/dewitt.json',
                      curry(self._OpenTestData, 'friendship-create.json'))
     user = self._api.CreateFriendship('dewitt')
     # This is rather arbitrary, but spot checking is better than nothing
@@ -448,7 +452,7 @@ class ApiTest(unittest.TestCase):
 
   def testDestroyFriendship(self):
     '''Test the twitter.Api DestroyFriendship method'''
-    self._AddHandler('http://twitter.com/friendships/destroy/dewitt.json',
+    self._AddHandler('https://api.twitter.com/1/friendships/destroy/dewitt.json',
                      curry(self._OpenTestData, 'friendship-destroy.json'))
     user = self._api.DestroyFriendship('dewitt')
     # This is rather arbitrary, but spot checking is better than nothing
@@ -456,7 +460,7 @@ class ApiTest(unittest.TestCase):
 
   def testGetUser(self):
     '''Test the twitter.Api GetUser method'''
-    self._AddHandler('http://twitter.com/users/show/dewitt.json',
+    self._AddHandler('https://api.twitter.com/1/users/show/dewitt.json',
                      curry(self._OpenTestData, 'show-dewitt.json'))
     user = self._api.GetUser('dewitt')
     self.assertEqual('dewitt', user.screen_name)
@@ -471,7 +475,10 @@ class ApiTest(unittest.TestCase):
     return os.path.join(test_data_dir, filename)
 
   def _OpenTestData(self, filename):
-    return open(self._GetTestDataPath(filename))
+    f = open(self._GetTestDataPath(filename))
+    # make sure that the returned object contains an .info() method:
+    # headers are set to {}
+    return urllib.addinfo(f, {})
 
 class MockUrllib(object):
   '''A mock replacement for urllib that hardcodes specific responses.'''
@@ -486,6 +493,15 @@ class MockUrllib(object):
   def build_opener(self, *handlers):
     return MockOpener(self._handlers)
 
+  def HTTPHandler(self, *args, **kwargs):
+      return None
+
+  def HTTPSHandler(self, *args, **kwargs):
+      return None
+  
+  def OpenerDirector(self):
+      return self.build_opener()
+
 class MockOpener(object):
   '''A mock opener for urllib'''
 
@@ -496,11 +512,28 @@ class MockOpener(object):
   def open(self, url, data=None):
     if self._opened:
       raise Exception('MockOpener already opened.')
+  
+    # Remove parameters from URL - they're only added by oauth and we
+    # don't want to test oauth 
+    if '?' in url:
+        # We split using & and filter on the beginning of each key
+        # This is crude but we have to keep the ordering for now
+        (url, qs) = url.split('?')
+        
+        tokens = [token for token in qs.split('&') 
+                  if not token.startswith('oauth')]
+        
+        if len(tokens) > 0:
+            url = "%s?%s"%(url, '&'.join(tokens))
+  
     if url in self._handlers:
       self._opened = True
       return self._handlers[url]()
     else:
-      raise Exception('Unexpected URL %s' % url)
+      raise Exception('Unexpected URL %s (Checked: %s)' % (url, self._handlers))
+
+  def add_handler(self, *args, **kwargs):
+      pass
 
   def close(self):
     if not self._opened:
@@ -514,23 +547,6 @@ class MockHTTPBasicAuthHandler(object):
     # TODO(dewitt): Add verification that the proper args are passed
     pass
 
-
-class NullCache(object):
-  '''A no-op replacement for the cache class'''
-
-  def Get(self, key):
-    return None
-
-  def Set(self, key, data):
-    pass
-
-  def Remove(self, key):
-    pass
-
-  def GetCachedTime(self, key):
-    return None
-
-
 class curry:
   # http://aspn.activestate.com/ASPN/Cookbook/Python/Recipe/52549
 
